#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.0.35
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver_full %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)
%define pa_ver_major_minor %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1 | cut -d "." -f 1,2)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 14.2
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-gui-common-devel >= 3.2.0
BuildRequires:	qubes-db-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan-xen
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-server-Xorg
Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver_full}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver_full} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make BACKEND_VMM=xen appvm

%install
rm -rf $RPM_BUILD_ROOT
make install install-xfce DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER_FULL=%{pa_ver_full}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
/etc/profile.d/qubes-session.sh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/qubes-keymap.sh
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
%config /etc/sysconfig/desktop
/etc/sysconfig/modules/qubes-u2mfn.modules
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/modules-load.d/qubes-gui.conf
/usr/lib/tmpfiles.d/qubes-session.conf
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver_major_minor}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/50-xfce-desktop.sh

%changelog
* Wed Jan 27 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux.git

* Wed Jan 27 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5245d06
- version 4.0.35

* Wed Jan 27 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4833e93
- Add pulseaudio 14.2 headers

* Mon Jan 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f60e430
- Add pulseaudio-14.1 headers

* Sun Jan 17 2021 unman <unman@thirdeyesecurity.org> - e50e43b
- Fix pulseaudio in Ubuntu templates

* Sat Jan 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 375e8cd
- version 4.0.34

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c962812
- debian: prevent restart on update

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d18e56c
- version 4.0.33

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 33262cc
- Avoid passing NULL as an X11 string

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 1635e14
- Tell Java we are a non-reparenting window manager

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 71aa280
- Only set focus on windows that want it

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 8f5fcc1
- Log when an unmanaged window is skipped

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 5ad04b4
- Remove unnecessary XInternAtom

* Fri Jan 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6916a48
- debian: update compat

* Fri Jan 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 4b909cf
- debian: update control

* Fri Jan 08 2021 Benjamin Moody <benjaminmoody@gmail.com> - 21c0474
- vmside: Implement the WM_STATE property.

* Fri Jan 08 2021 Benjamin Moody <benjaminmoody@gmail.com> - 0dfab6e
- vmside: Rename wm_state to net_wm_state.

* Sat Dec 05 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8317c6c
- version 4.0.32

* Sat Dec 05 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 87b2f02
- Add pulseaudio-14.0 headers

* Sat Dec 05 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 27637a3
- Fix Unicode handling in Qubes clipboard

* Sat Dec 05 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ed8328d
- Add .gitlab-ci.yml

* Sat Dec 05 2020 icequbes1 <71958531+icequbes1@users.noreply.github.com> - 81b3d39
- Link pulsecore 13.99.3 headers to 13.99.2

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 23b453b
- version 4.0.31

* Sat Oct 17 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ab02e1a
- pulseaudio: allow bluetooth devices like headphones

* Sat Oct 17 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 984cc1e
- Makefile: add clean of pkgs and debian changelog.*

* Sat Oct 17 2020 deathgrippin <57326449+deathgrippin@users.noreply.github.com> - 3a15a00
- Condense conditional

* Sat Oct 17 2020 Rusty Bird <rustybird@net-c.com> - a91f172
- vmside: use XKillClient() if WM_DELETE_WINDOW is unsupported

* Sat Oct 10 2020 unman <unman@thirdeyesecurity.org> - e16ad01
- pulseaudio 13.99.2

* Sat Oct 10 2020 unman <unman@thirdeyesecurity.org> - 6deb0ba
- pulseaudio 13.99.2: add internal headers

* Sun Aug 23 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ac6721d
- version 4.0.30

* Sun Aug 23 2020 Matt McCutchen <matt@mattmccutchen.net> - 6e3411d
- module-vchan-sink: link up the card properly

* Tue Jun 02 2020 Olivier MEDOC <o_medoc@yahoo.fr> - 35b0f3c
- archlinux: set dependencies on xorg server ABI version instead of the server version itself

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3a33abf
- version 4.0.29

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6493688
- travis: use imported config

* Sat Apr 18 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 9186332
- pulseaudio 13.99.1

* Sat Apr 18 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - d848bf1
- pulseaudio 13.99.1: add internal headers

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 73be82a
- version 4.0.28

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a4182f5
- pulse: fix pa_proplist_set[fs] usage

* Sat Apr 18 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 22e6859
- pulseaudio: support reconnecting

* Sat Apr 18 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9269574
- module-vchan-sink: log for domid used

* Sat Apr 18 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f0d6adf
- module-vchan-sink: convert tabs to spaces

* Sat Apr 18 2020 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - c052ef0
- add modargs for target domid and sink/source descr strings

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d03b6a1
- create /etc/qubes-rpc directory before placing a symlink there

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - db11553
- Replace non-executable qubes.SetMonitorLayout file with a symlink

* Wed Apr 01 2020 Yukikoo <github@neowutran.ovh> - ddedb60
- Archlinux: more permissive with xorg-server update

* Sun Jan 19 2020 Zaoqi <zaomir@outlook.com> - 59a3e33
- archlinux: qubes-vm-gui: update PKGBUILD

* Wed Dec 25 2019 Neowutran <me@neowutran.ovh> - 36b1f6b
- ARCHLINUX: Allow xorg-server<1.20.7

* Wed Dec 25 2019 Neowutran <me@neowutran.ovh> - 0e36534
- ARCHLINUX: xf86dgaproto doesn't exist anymore, and is no longer required. Removing it from the dependencies.

* Sun Oct 20 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ab6d95c
- travis: switch to bionic

* Mon Oct 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4f2a157
- version 4.0.27

* Mon Oct 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1c0bfa6
- Escape '$p' in systemd unit file

